// main entry point into the server program

"use strict";

import express from "express";
import session from "express-session";
import mongoStore from "connect-mongo";

import todoRouter from "./routes/todo.mjs";

import { initDb, getClient } from "./models/db.mjs";

// connect to MongoDB and then spin up our server
initDb().then(() => {
    // create an application object
    const app = express();

    // create our session store
    const store = mongoStore.create({
        client: getClient(),
        dbName: "ToDoApp",
        touchAfter: 24 * 3600 // every 24 hours
    });

    // session settings
    const sess = {
        secret: "SLU CS332",
        cookie: {},
        store: store,
        resave: false,
        saveUninitialized: false
    };

    // tell app to use the session
    app.use(session(sess));

    // parse the body of request objects as json
    app.use(express.json());

    // serve static files from the public folder in this package
    // if no other "middleware" function (request handler) fires,
    // look for the page requested in the public folder
    app.use(express.static("public"));

    app.use("/api", todoRouter);

    // TODO
    // add all of our request handlers to this app
    // object
    app.get("/", (req, resp) => {
        // req object contains all information about the incoming request
        // resp object allows us to modify the response object before
        // express sends it back to the user

        // json methon will send json data back to the client
        resp.json({
            "beep": "boop",
            "hello": "world"
        });
    });


    // TODO GET /add add an x and y request value and return the result
    // as { result: x + y }
    app.get("/add", (req, res) => {
        const x = parseInt(req.query.x);
        const y = parseInt(req.query.y);
        res.json({
            result: x + y
        });
    });


    // turn the app into a server
    const server = app.listen(3001);
    server.on("listening", () => {
        console.log(`Listening on ${server.address().port}.`)
    });
});

